pub struct SigHasher {
precomputed_tx_data: PrecomputedTxData,
}Expand description
A SigHasher context which stores precomputed data that is reused between sighash computations for the same transaction.
Fields
precomputed_tx_data: PrecomputedTxDataImplementations
Sourceimpl SigHasher
impl SigHasher
Sourcepub fn new(
trans: &Transaction,
nu: NetworkUpgrade,
all_previous_outputs: Arc<Vec<Output>>,
) -> Result<Self, Error>
pub fn new( trans: &Transaction, nu: NetworkUpgrade, all_previous_outputs: Arc<Vec<Output>>, ) -> Result<Self, Error>
Create a new SigHasher for the given transaction.
Panics
- If
transcan’t be converted to itslibrustzcashequivalent. This could happen, for example, iftranscontains thenConsensusBranchIdfield, andnudoesn’t match it. More details inPrecomputedTxData::new. - If
nudoesn’t contain a consensus branch id convertible to itslibrustzcashequivalent.
Sourcepub fn sighash(
&self,
hash_type: HashType,
input_index_script_code: Option<(usize, Vec<u8>)>,
) -> SigHash
pub fn sighash( &self, hash_type: HashType, input_index_script_code: Option<(usize, Vec<u8>)>, ) -> SigHash
Calculate the sighash for the current transaction.
Details
The input_index_script_code tuple indicates the index of the
transparent Input for which we are producing a sighash and the
respective script code being validated, or None if it’s a shielded
input.
Panics
- if the input index is out of bounds for self.inputs()
Sourcepub fn orchard_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
pub fn orchard_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
Returns the Orchard bundle in the precomputed transaction data.
Sourcepub fn sapling_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
pub fn sapling_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
Returns the Sapling bundle in the precomputed transaction data.